# About Launchable

[Launchable](https://www.launchableinc.com) is a **software testing intelligence platform**.

Using data from your CI runs, Launchable  provides actions and insights to speed up your testing workflow so you can ship high quality software faster:

* [**Predictive Test Selection**](actions/predictive-test-selection/) uses machine learning to select the right tests to run for a specific code change. This unlocks the ability to run a much smaller set of tests at various points in your software development lifecycle, accelerating delivery.
* [**Flaky Test Insights**](insights/flaky-tests.md) surfaces flaky tests in your test suite so you can fix them and run tests more reliably.

To get started, [contact our customer success team](https://www.launchableinc.com/contact-for-poc) to initiate an enterprise proof of concept (POC), or [sign up](https://app.launchableinc.com/signup) directly from our website. (Launchable is free for open source projects.)

{% hint style="info" %}
Launchable is a cloud-based software-as-a-service (SaaS) product.
{% endhint %}
